@@ -34,6 +34,10 @@ def extract():
                         else:
                             __main__.change_type = commands.get('version')
                         
+                        if commands.get('branch'):
+                            __main__.branch = commands.get('branch')
+                            print("INFO: Branch specified: ", __main__.branch)
+                        
                         # Fetch pre release value
                         if commands.get('preValue'):
                             __main__.pre_value = commands.get('preValue')
